@@ -77,151 +77,11 @@ class GamutCanvas(LUTCanvas):
 		polys = []
 
 		# L*a*b*
-		optimalcolors = [(52.40, 95.40, 10.58),
-						 (52.33, 91.23, 38.56),
-						 (52.31, 89.09, 65.80),
-						 (52.30, 88.24, 89.93),
-						 (59.11, 84.13, 101.46),
-						 (66.02, 75.66, 113.09),
-						 (72.36, 64.33, 123.65),
-						 (78.27, 50.88, 132.94),
-						 (83.64, 36.33, 140.63),
-						 (88.22, 22.05, 145.02),
-						 (92.09, 8.49, 143.95),
-						 (90.38, -4.04, 141.05),
-						 (87.54, -23.02, 136.16),
-						 (85.18, -37.06, 132.16),
-						 (82.10, -52.65, 126.97),
-						 (85.53, -65.59, 122.51),
-						 (82.01, -81.46, 116.55),
-						 (77.35, -97.06, 108.72),
-						 (74.76, -122.57, 90.91),
-						 (68.33, -134.27, 80.11),
-						 (63.07, -152.99, 56.41),
-						 (54.57, -159.74, 42.75),
-						 (44.43, -162.58, 27.45),
-						 (46.92, -162.26, 13.87),
-						 (48.53, -144.04, -4.73),
-						 (49.50, -115.82, -25.38),
-						 (59.18, -85.50, -47.00),
-						 (59.33, -68.64, -58.79),
-						 (59.41, -52.73, -69.57),
-						 (50.80, -25.33, -84.08),
-						 (42.05, 8.67, -98.57),
-						 (33.79, 43.74, -111.63),
-						 (26.63, 74.31, -121.90),
-						 (20.61, 98.44, -128.77),
-						 (14.87, 117.34, -131.97),
-						 (9.74, 127.16, -129.59),
-						 (5.20, 125.79, -120.43),
-						 (7.59, 122.01, -116.33),
-						 (10.21, 117.89, -111.81),
-						 (26.35, 115.11, -100.95),
-						 (40.68, 115.59, -87.47),
-						 (39.37, 115.48, -78.51),
-						 (46.49, 114.84, -66.24),
-						 (53.49, 111.63, -54.17),
-						 (52.93, 107.54, -38.16),
-						 (52.58, 101.53, -16.45),
-						 (52.40, 95.40, 10.58)]
+		optimalcolors = colormath.optimalcolors_Lab
 
 		# CIE 1931 2-deg chromaticity coordinates
 		# http://www.cvrl.org/offercsvccs.php
-		xy = [(0.175560, 0.005294),
-			  (0.175161, 0.005256),
-			  (0.174821, 0.005221),
-			  (0.174510, 0.005182),
-			  (0.174112, 0.004964),
-			  (0.174008, 0.004981),
-			  (0.173801, 0.004915),
-			  (0.173560, 0.004923),
-			  (0.173337, 0.004797),
-			  (0.173021, 0.004775),
-			  (0.172577, 0.004799),
-			  (0.172087, 0.004833),
-			  (0.171407, 0.005102),
-			  (0.170301, 0.005789),
-			  (0.168878, 0.006900),
-			  (0.166895, 0.008556),
-			  (0.164412, 0.010858),
-			  (0.161105, 0.013793),
-			  (0.156641, 0.017705),
-			  (0.150985, 0.022740),
-			  (0.143960, 0.029703),
-			  (0.135503, 0.039879),
-			  (0.124118, 0.057803),
-			  (0.109594, 0.086843),
-			  (0.091294, 0.132702),
-			  (0.068706, 0.200723),
-			  (0.045391, 0.294976),
-			  (0.023460, 0.412703),
-			  (0.008168, 0.538423),
-			  (0.003859, 0.654823),
-			  (0.013870, 0.750186),
-			  (0.038852, 0.812016),
-			  (0.074302, 0.833803),
-			  (0.114161, 0.826207),
-			  (0.154722, 0.805864),
-			  (0.192876, 0.781629),
-			  (0.229620, 0.754329),
-			  (0.265775, 0.724324),
-			  (0.301604, 0.692308),
-			  (0.337363, 0.658848),
-			  (0.373102, 0.624451),
-			  (0.408736, 0.589607),
-			  (0.444062, 0.554714),
-			  (0.478775, 0.520202),
-			  (0.512486, 0.486591),
-			  (0.544787, 0.454434),
-			  (0.575151, 0.424232),
-			  (0.602933, 0.396497),
-			  (0.627037, 0.372491),
-			  (0.648233, 0.351395),
-			  (0.665764, 0.334011),
-			  (0.680079, 0.319747),
-			  (0.691504, 0.308342),
-			  (0.700606, 0.299301),
-			  (0.707918, 0.292027),
-			  (0.714032, 0.285929),
-			  (0.719033, 0.280935),
-			  (0.723032, 0.276948),
-			  (0.725992, 0.274008),
-			  (0.728272, 0.271728),
-			  (0.729969, 0.270031),
-			  (0.731089, 0.268911),
-			  (0.731993, 0.268007),
-			  (0.732719, 0.267281),
-			  (0.733417, 0.266583),
-			  (0.734047, 0.265953),
-			  (0.734390, 0.265610),
-			  (0.734592, 0.265408),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734548, 0.265452),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310),
-			  (0.734690, 0.265310)]
+		xy = colormath.cie1931_2_xy
 
 		if self.colorspace == "xy":
 			label_x = "x"
@@ -273,12 +133,8 @@ class GamutCanvas(LUTCanvas):
 			min_y = -50.0
 			step = 25
 		elif self.colorspace in ("DIN99b", "DIN99c", "DIN99d"):
-			if self.colorspace == "DIN99c":
-				label_x = "a99c"
-				label_y = "b99c"
-			else:
-				label_x = "a99d"
-				label_y = "b99d"
+			label_x = "a" + self.colorspace[3:]
+			label_y = "b" + self.colorspace[3:]
 			max_x = 65.0
 			max_y = 65.0
 			min_x = -65.0
@@ -999,6 +855,46 @@ class GamutViewOptions(wx_Panel):
 		self.Thaw()
 
 
+class PIFrame_2WaySplitter(TwoWaySplitter):
+
+	def OnLeftDClick(self, event):
+		if not self.IsEnabled():
+			return
+		
+		pt = event.GetPosition()
+
+		if self.GetMode(pt):
+			
+			barSize = self._GetSashSize()
+
+			winborder, titlebar = get_platform_window_decoration_size()
+
+			win0w = self.GetTopLeft().Size[0]
+
+			self.Freeze()
+			TwoWaySplitter.OnLeftDClick(self, event)
+			if self._expanded < 0:
+				self.Parent.SetMinSize((defaults["size.profile_info.split.w"] + winborder * 2,
+										self.Parent.GetMinSize()[1]))
+				if (not self.Parent.IsMaximized() and
+					self.Parent.GetSize()[0] < self.GetSplitSize()[0]):
+					self.Parent.SetSize((self.GetSplitSize()[0],
+										 self.Parent.GetSize()[1]))
+			else:
+				self.Parent.SetMinSize((defaults["size.profile_info.w"] + winborder * 2,
+										self.Parent.GetMinSize()[1]))
+				w = max(self.GetExpandedSize()[0],
+						self._splitx + barSize + winborder * 2)
+				if (not self.Parent.IsMaximized() and
+					self.Parent.GetSize()[0] > w):
+					self.Parent.SetSize((w,
+										 self.Parent.GetSize()[1]))
+			if self.GetTopLeft().Size[0] != win0w:
+				self.Parent.redraw()
+			self.Parent.resize_grid()
+			self.Thaw()
+
+
 class ProfileInfoFrame(LUTFrame):
 
 	def __init__(self, *args, **kwargs):
@@ -1020,7 +916,9 @@ class ProfileInfoFrame(LUTFrame):
 		self.sizer = wx.BoxSizer(wx.VERTICAL)
 		self.SetSizer(self.sizer)
 		
-		self.splitter = TwoWaySplitter(self, -1, agwStyle = wx.SP_LIVE_UPDATE | wx.SP_NOSASH)
+		self.splitter = PIFrame_2WaySplitter(self, -1,
+											 agwStyle=wx.SP_LIVE_UPDATE |
+													  wx.SP_NOSASH)
 		self.sizer.Add(self.splitter, 1, flag=wx.EXPAND)
 		
 		p1 = wx_Panel(self.splitter, name="canvaspanel")
@@ -1560,7 +1458,8 @@ class ProfileInfoFrame(LUTFrame):
 		wx.CallAfter(self.resize_grid)
 	
 	def OnSize(self, event=None):
-		if self.IsShownOnScreen() and self.IsMaximized():
+		if (self.IsShownOnScreen() and self.IsMaximized() and
+			self.splitter._expanded < 0):
 			self.splitter.AdjustLayout()
 		self.splitter.Refresh()
 		wx.CallAfter(self.redraw)
@@ -1941,7 +1840,7 @@ def _main(app):
 	display_no = get_argyll_display_number(app.TopWindow.get_display()[1])
 	for arg in sys.argv[1:]:
 		if os.path.isfile(arg):
-			app.TopWindow.drop_handler(safe_unicode(arg))
+			app.TopWindow.drop_handler(safe_unicode(os.path.abspath(arg)))
 			break
 	else:
 		app.TopWindow.LoadProfile(get_display_profile(display_no))
