@@ -7,7 +7,11 @@ import threading
 import types
 
 from colormath import specialpow
-from wxfixes import wx
+from wxfixes import wx, GenButton, PlateButton, get_dialogs
+
+import wx.grid
+from lib.agw.gradientbutton import GradientButton
+import floatspin
 
 
 def AdjustMinMax(self, minvalue=0.0, maxvalue=1.0):
@@ -36,6 +40,15 @@ def Invert(self):
 wx.Image.Invert = Invert
 
 
+def GammaCorrect(self, from_gamma=-2.4, to_gamma=1.8):
+	""" Gamma correct """
+	buffer = self.GetDataBuffer()
+	for i, byte in enumerate(buffer):
+		buffer[i] = chr(int(round(specialpow(ord(byte) / 255., from_gamma) ** (1.0 / to_gamma) * 255)))
+
+wx.Image.GammaCorrect = GammaCorrect
+
+
 def IsBW(self):
 	"""
 	Check if image is grayscale in the most effective way possible.
@@ -510,15 +523,22 @@ class ThreadedCallLater(ThreadedTimer):
 
 class BetterWindowDisabler(object):
 	
-	""" Also disables child windows instead of only top level windows. This is
+	"""
+	Also disables child windows instead of only top level windows. This is
 	actually needed under Mac OS X where disabling a top level window will
-	not prevent interaction with its children. """
+	not prevent interaction with its children.
+	
+	If toplevelparent is given, disable only this window and its child windows.
+	
+	"""
 	
 	windows = set()
 
-	def __init__(self, skip=None):
+	def __init__(self, skip=None, toplevelparent=None, include_menus=False):
 		self._windows = []
 		self.skip = skip
+		self.toplevelparent = toplevelparent
+		self.include_menus = include_menus
 		self.disable()
 
 	def __del__(self):
@@ -533,18 +553,46 @@ class BetterWindowDisabler(object):
 			if skip:
 				if not isinstance(skip, (list, tuple)):
 					skip = [skip]
-			toplevel = list(wx.GetTopLevelWindows())
+			if self.toplevelparent:
+				toplevel = [self.toplevelparent]
+			else:
+				toplevel = list(wx.GetTopLevelWindows())
 			for w in toplevel:
 				if (w and w not in skip and "Inspection" not in "%s" % w and
 					w not in BetterWindowDisabler.windows):
 					self._windows.append(w)
+					# Selectively add children to our list of handled
+					# windows. This prevents a segfault with wxPython 4
+					# under macOS where GetAllChildren includes sub-controls
+					# of controls, like scrollbars etc.
 					for child in w.GetAllChildren(skip + toplevel):
-						if (child and not isinstance(child, (wx.Panel,
-															 wx.PyPanel)) and
+						if (child and isinstance(child, (wx.BitmapButton,
+														 wx.Button,
+														 wx.CheckBox,
+														 wx.Choice,
+														 wx.ComboBox,
+														 wx.ListBox,
+														 wx.ListCtrl,
+														 wx.RadioButton,
+														 wx.SpinCtrl,
+														 wx.Slider,
+														 wx.StaticText,
+														 wx.TextCtrl,
+														 wx.grid.Grid,
+														 floatspin.FloatSpin,
+														 GenButton,
+														 GradientButton,
+														 PlateButton)) and
 							child not in BetterWindowDisabler.windows):
 							# Don't disable panels, this can have weird side
 							# effects for contained controls
 							self._windows.append(child)
+					if self.include_menus:
+						menubar = w.GetMenuBar()
+						if menubar:
+							for menu, label in menubar.GetMenus():
+								for item in menu.GetMenuItems():
+									self._windows.append(item)
 			def Enable(w, enable=True):
 				w._BetterWindowDisabler_enabled = enable
 			def Disable(w):
@@ -552,9 +600,10 @@ class BetterWindowDisabler(object):
 			for w in reversed(self._windows):
 				BetterWindowDisabler.windows.add(w)
 				enabled = w.IsEnabled()
-				w.Disable()
-				w._BetterWindowDisabler_Disable = w.Disable
-				w.Disable = types.MethodType(Disable, w, type(w))
+				w.Enable(False)
+				if hasattr(w, "Disable"):
+					w._BetterWindowDisabler_Disable = w.Disable
+					w.Disable = types.MethodType(Disable, w, type(w))
 				w._BetterWindowDisabler_Enable = w.Enable
 				w.Enable = types.MethodType(Enable, w, type(w))
 				w.Enable(enabled)
@@ -593,6 +642,13 @@ class FileDrop(wx.FileDropTarget):
 		self.unsupported_handler = None
 
 	def OnDropFiles(self, x, y, filenames):
+		dialogs = get_dialogs()
+		interactable = (not hasattr(self, "parent") or
+						(self.parent.Enabled and
+						 (not dialogs or self.parent in dialogs)))
+		if not interactable:
+			wx.Bell()
+			return False
 		self._files = []
 		self._filenames = filenames
 
